@@ -25,8 +25,7 @@ from torchmetrics.utilities.imports import _TORCH_LOWER_1_6
 
 
 class AUROC(Metric):
-    r"""Compute `Area Under the Receiver Operating Characteristic Curve (ROC AUC)
-    <https://en.wikipedia.org/wiki/Receiver_operating_characteristic#Further_interpretations>`_.
+    r"""Compute Area Under the Receiver Operating Characteristic Curve (`ROC AUC`_).
     Works for both binary, multilabel and multiclass problems. In the case of
     multiclass, the values will be calculated based on a one-vs-the-rest approach.
 
@@ -107,7 +106,7 @@ class AUROC(Metric):
         self,
         num_classes: Optional[int] = None,
         pos_label: Optional[int] = None,
-        average: Optional[str] = 'macro',
+        average: Optional[str] = "macro",
         max_fpr: Optional[float] = None,
         compute_on_step: bool = True,
         dist_sync_on_step: bool = False,
@@ -126,10 +125,10 @@ class AUROC(Metric):
         self.average = average
         self.max_fpr = max_fpr
 
-        allowed_average = (None, 'macro', 'weighted', 'micro')
+        allowed_average = (None, "macro", "weighted", "micro")
         if self.average not in allowed_average:
             raise ValueError(
-                f'Argument `average` expected to be one of the following: {allowed_average} but got {average}'
+                f"Argument `average` expected to be one of the following: {allowed_average} but got {average}"
             )
 
         if self.max_fpr is not None:
@@ -138,7 +137,7 @@ class AUROC(Metric):
 
             if _TORCH_LOWER_1_6:
                 raise RuntimeError(
-                    '`max_fpr` argument requires `torch.bucketize` which is not available below PyTorch version 1.6'
+                    "`max_fpr` argument requires `torch.bucketize` which is not available below PyTorch version 1.6"
                 )
 
         self.mode: DataType = None  # type: ignore
@@ -146,13 +145,12 @@ class AUROC(Metric):
         self.add_state("target", default=[], dist_reduce_fx="cat")
 
         rank_zero_warn(
-            'Metric `AUROC` will save all targets and predictions in buffer.'
-            ' For large datasets this may lead to large memory footprint.'
+            "Metric `AUROC` will save all targets and predictions in buffer."
+            " For large datasets this may lead to large memory footprint."
         )
 
     def update(self, preds: Tensor, target: Tensor) -> None:  # type: ignore
-        """
-        Update state with predictions and targets.
+        """Update state with predictions and targets.
 
         Args:
             preds: Predictions from model (probabilities, or labels)
@@ -165,15 +163,13 @@ class AUROC(Metric):
 
         if self.mode and self.mode != mode:
             raise ValueError(
-                'The mode of data (binary, multi-label, multi-class) should be constant, but changed'
-                f' between batches from {self.mode} to {mode}'
+                "The mode of data (binary, multi-label, multi-class) should be constant, but changed"
+                f" between batches from {self.mode} to {mode}"
             )
         self.mode = mode
 
     def compute(self) -> Tensor:
-        """
-        Computes AUROC based on inputs passed in to ``update`` previously.
-        """
+        """Computes AUROC based on inputs passed in to ``update`` previously."""
         if not self.mode:
             raise RuntimeError("You have to have determined mode.")
         preds = dim_zero_cat(self.preds)
@@ -190,8 +186,6 @@ class AUROC(Metric):
 
     @property
     def is_differentiable(self) -> bool:
-        """
-        AUROC metrics is considered as non differentiable
-         so it should have `false` value for `is_differentiable` property
-        """
+        """AUROC metrics is considered as non differentiable so it should have `false` value for
+        `is_differentiable` property."""
         return False
