@@ -20,11 +20,24 @@ _matthews_corrcoef_update = _confusion_matrix_update
 
 
 def _matthews_corrcoef_compute(confmat: Tensor) -> Tensor:
+    """Computes Matthews correlation coefficient.
+
+    Args:
+        confmat: Confusion matrix
+
+    Example:
+        >>> target = torch.tensor([1, 1, 0, 0])
+        >>> preds = torch.tensor([0, 1, 0, 0])
+        >>> confmat = _matthews_corrcoef_update(preds, target, num_classes=2)
+        >>> _matthews_corrcoef_compute(confmat)
+        tensor(0.5774)
+    """
+
     tk = confmat.sum(dim=1).float()
     pk = confmat.sum(dim=0).float()
     c = torch.trace(confmat).float()
     s = confmat.sum().float()
-    return (c * s - sum(tk * pk)) / (torch.sqrt(s**2 - sum(pk * pk)) * torch.sqrt(s**2 - sum(tk * tk)))
+    return (c * s - sum(tk * pk)) / (torch.sqrt(s ** 2 - sum(pk * pk)) * torch.sqrt(s ** 2 - sum(tk * tk)))
 
 
 def matthews_corrcoef(
@@ -34,8 +47,7 @@ def matthews_corrcoef(
     threshold: float = 0.5,
 ) -> Tensor:
     r"""
-    Calculates `Matthews correlation coefficient
-    <https://en.wikipedia.org/wiki/Matthews_correlation_coefficient>`_ that measures
+    Calculates `Matthews correlation coefficient`_ that measures
     the general correlation or quality of a classification. In the binary case it
     is defined as:
 
