@@ -28,6 +28,29 @@ def _specificity_compute(
     average: str,
     mdmc_average: Optional[str],
 ) -> Tensor:
+    """Computes specificity from the stat scores: true positives, false positives, true negatives, false negatives.
+
+    Args:
+        tp: True positives
+        fp: False positives
+        tn: True negatives
+        fn: False negatives
+        average: Defines the reduction that is applied
+        mdmc_average: Defines how averaging is done for multi-dimensional multi-class inputs (on top of the
+            ``average`` parameter)
+
+    Example:
+        >>> from torchmetrics.functional.classification.stat_scores import _stat_scores_update
+        >>> preds  = torch.tensor([2, 0, 2, 1])
+        >>> target = torch.tensor([1, 1, 2, 0])
+        >>> tp, fp, tn, fn = _stat_scores_update(preds, target, reduce='macro', num_classes=3)
+        >>> _specificity_compute(tp, fp, tn, fn, average='macro', mdmc_average=None)
+        tensor(0.6111)
+        >>> tp, fp, tn, fn = _stat_scores_update(preds, target, reduce='micro')
+        >>> _specificity_compute(tp, fp, tn, fn, average='micro', mdmc_average=None)
+        tensor(0.6250)
+    """
+
     numerator = tn
     denominator = tn + fp
     if average == AverageMethod.NONE and mdmc_average != MDMCAverageMethod.SAMPLEWISE:
