@@ -20,7 +20,7 @@ from torchmetrics.utilities.checks import _check_same_shape
 
 
 def _find_repeats(data: Tensor) -> Tensor:
-    """ find and return values which have repeats i.e. the same value are more than once in the tensor """
+    """find and return values which have repeats i.e. the same value are more than once in the tensor."""
     temp = data.detach().clone()
     temp = temp.sort()[0]
 
@@ -33,9 +33,9 @@ def _find_repeats(data: Tensor) -> Tensor:
 
 
 def _rank_data(data: Tensor) -> Tensor:
-    """ Calculate the rank for each element of a tensor. The rank refers to the indices of an element in the
-    corresponding sorted tensor (starting from 1). Duplicates of the same value will be assigned the mean of
-    their rank
+    """Calculate the rank for each element of a tensor. The rank refers to the indices of an element in the
+    corresponding sorted tensor (starting from 1). Duplicates of the same value will be assigned the mean of their
+    rank.
 
     Adopted from:
         https://github.com/scipy/scipy/blob/v1.6.2/scipy/stats/stats.py#L4140-L4303
@@ -47,12 +47,20 @@ def _rank_data(data: Tensor) -> Tensor:
 
     repeats = _find_repeats(data)
     for r in repeats:
-        condition = rank == r
+        condition = data == r
         rank[condition] = rank[condition].mean()
     return rank
 
 
 def _spearman_corrcoef_update(preds: Tensor, target: Tensor) -> Tuple[Tensor, Tensor]:
+    """Updates and returns variables required to compute Spearman Correlation Coefficient. Checks for same shape
+    and type of input tensors.
+
+    Args:
+        preds: Predicted tensor
+        target: Ground truth tensor
+    """
+
     if preds.dtype != target.dtype:
         raise TypeError(
             "Expected `preds` and `target` to have the same data type."
@@ -62,11 +70,26 @@ def _spearman_corrcoef_update(preds: Tensor, target: Tensor) -> Tuple[Tensor, Te
     preds = preds.squeeze()
     target = target.squeeze()
     if preds.ndim > 1 or target.ndim > 1:
-        raise ValueError('Expected both predictions and target to be 1 dimensional tensors.')
+        raise ValueError("Expected both predictions and target to be 1 dimensional tensors.")
     return preds, target
 
 
 def _spearman_corrcoef_compute(preds: Tensor, target: Tensor, eps: float = 1e-6) -> Tensor:
+    """Computes Spearman Correlation Coefficient.
+
+    Args:
+        preds: Predicted tensor
+        target: Ground truth tensor
+        eps: Avoids ZeroDivisionError. default: 1e-6
+
+    Example:
+        >>> target = torch.tensor([3, -0.5, 2, 7])
+        >>> preds = torch.tensor([2.5, 0.0, 2, 8])
+        >>> preds, target = _spearman_corrcoef_update(preds, target)
+        >>> _spearman_corrcoef_compute(preds, target)
+        tensor(1.0000)
+    """
+
     preds = _rank_data(preds)
     target = _rank_data(target)
 
@@ -83,8 +106,7 @@ def _spearman_corrcoef_compute(preds: Tensor, target: Tensor, eps: float = 1e-6)
 
 def spearman_corrcoef(preds: Tensor, target: Tensor) -> Tensor:
     r"""
-     Computes `spearmans rank correlation coefficient
-     <https://en.wikipedia.org/wiki/Spearman%27s_rank_correlation_coefficient>`_:
+     Computes `spearmans rank correlation coefficient`_:
 
     .. math:
         r_s = = \frac{cov(rg_x, rg_y)}{\sigma_{rg_x} * \sigma_{rg_y}}
