@@ -14,20 +14,19 @@
 from typing import Optional
 
 import torch
-from torch import Tensor, tensor
+from torch import Tensor
 
 from torchmetrics.utilities.checks import _check_retrieval_functional_inputs
 
 
 def _dcg(target: Tensor) -> Tensor:
+    """Computes Discounted Cumulative Gain for input tensor."""
     denom = torch.log2(torch.arange(target.shape[-1], device=target.device) + 2.0)
-    return (target / denom).sum()
+    return (target / denom).sum(dim=-1)
 
 
 def retrieval_normalized_dcg(preds: Tensor, target: Tensor, k: Optional[int] = None) -> Tensor:
-    """
-    Computes Normalized Discounted Cumulative Gain (for information retrieval), as explained
-    `here <https://en.wikipedia.org/wiki/Discounted_cumulative_gain>`__.
+    """Computes `Normalized Discounted Cumulative Gain`_ (for information retrieval).
 
     ``preds`` and ``target`` should be of the same shape and live on the same device.
     ``target`` must be either `bool` or `integers` and ``preds`` must be `float`,
@@ -55,10 +54,15 @@ def retrieval_normalized_dcg(preds: Tensor, target: Tensor, k: Optional[int] = N
     if not (isinstance(k, int) and k > 0):
         raise ValueError("`k` has to be a positive integer or None")
 
-    if not target.sum():
-        return tensor(0.0, device=preds.device)
-
     sorted_target = target[torch.argsort(preds, dim=-1, descending=True)][:k]
     ideal_target = torch.sort(target, descending=True)[0][:k]
 
-    return _dcg(sorted_target) / _dcg(ideal_target)
+    ideal_dcg = _dcg(ideal_target)
+    target_dcg = _dcg(sorted_target)
+
+    # filter undefined scores
+    all_irrelevant = ideal_dcg == 0
+    target_dcg[all_irrelevant] = 0
+    target_dcg[~all_irrelevant] /= ideal_dcg[~all_irrelevant]
+
+    return target_dcg.mean()
